# -*- coding: utf-8 -*-

"""
kaoru
~~~~~~~~

The very basics

:copyright: (c) 2015 by Alejandro Ricoveri
:license: MIT, see LICENSE for more details.

"""

PKG_URL = 'https://github.com/axltxl/kaoru'
__name__ = 'kaoru'
__author__ = 'Alejandro Ricoveri'
__version__ = '0.5.0'
__licence__ = 'MIT'
__copyright__ = 'Copyright (c) Alejandro Ricoveri'
